@@ -57,7 +57,7 @@ $YAHOO_CURRENCY_URL = "http://finance.yahoo.com/d/quotes.csv?e=.csv&f=l1&s=";
                 currency_lookup/;
 @EXPORT_TAGS = ( all => [@EXPORT_OK]);
 
-our $VERSION = '1.24'; # VERSION
+our $VERSION = '1.25'; # VERSION
 
 $USE_EXPERIMENTAL_UA = 0;
 
@@ -647,6 +647,29 @@ sub parse_csv
        return @new;      # list of values that were comma-separated
 }
 
+# =======================================================================
+# parse_csv_semicolon (public object method)
+#
+# Grabbed from the Perl Cookbook. Parsing csv isn't as simple as you thought!
+#
+sub parse_csv_semicolon
+{
+    shift if (ref $_[0]); # Shift off the object if we have one.
+    my $text = shift;      # record containing comma-separated values
+    my @new  = ();
+
+    push(@new, $+) while $text =~ m{
+        # the first part groups the phrase inside the quotes.
+        # see explanation of this pattern in MRE
+        "([^\"\\]*(?:\\.[^\"\\]*)*)";?
+           |  ([^;]+);?
+           | ;
+       }gx;
+       push(@new, undef) if substr($text, -1,1) eq ';';
+
+       return @new;      # list of values that were comma-separated
+}
+
 # =======================================================================
 # store_date (public object method)
 #
